==> Pyrogram-0.12.0-py3-none-any.whl: pyrogram/api/types/message_action_chat_delete_user.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class MessageActionChatDeleteUser(Object):
    """Attributes:
        ID: ``0xb2ae9b0c``

    Args:
        user_id: ``int`` ``32-bit``
    """

    __slots__ = ["user_id"]

    ID = 0xb2ae9b0c
    QUALNAME = "MessageActionChatDeleteUser"

    def __init__(self, *, user_id: int):
        self.user_id = user_id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "MessageActionChatDeleteUser":
        # No flags
        
        user_id = Int.read(b)
        
        return MessageActionChatDeleteUser(user_id=user_id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.user_id))
        
        return b.getvalue()

==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/types/message_action_chat_delete_user.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class MessageActionChatDeleteUser(Object):
    """Attributes:
        ID: ``0xb2ae9b0c``

    Parameters:
        user_id: ``int`` ``32-bit``
    """

    __slots__ = ["user_id"]

    ID = 0xb2ae9b0c
    QUALNAME = "types.MessageActionChatDeleteUser"

    def __init__(self, *, user_id: int):
        self.user_id = user_id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "MessageActionChatDeleteUser":
        # No flags
        
        user_id = Int.read(b)
        
        return MessageActionChatDeleteUser(user_id=user_id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.user_id))
        
        return b.getvalue()
